from distutils.core import setup
setup(
    name='rakshita',
    version='1.0.5',
    py_modules=['rakshita'],
    install_requires=['requests'],
    author='lovetocode',
    author_email='yogesh.chandra.iitbhu@gmail.com',
    description='pretty_list() function print the nested list in beautiful pattern',
)
